summaryrefslogtreecommitdiffstats
path: root/CMakeScripts
diff options
context:
space:
mode:
authorJohan B. C. Engelen <jbc.engelen@swissonline.ch>2008-03-30 19:27:10 +0000
committerjohanengelen <johanengelen@users.sourceforge.net>2008-03-30 19:27:10 +0000
commita7c884e1e6887444e52376ad48d961c36965d53f (patch)
treec6c2d879105a41c3b0d16875464467580115838f /CMakeScripts
parentclean up FindBoost.cmake (diff)
downloadinkscape-a7c884e1e6887444e52376ad48d961c36965d53f.tar.gz
inkscape-a7c884e1e6887444e52376ad48d961c36965d53f.zip
Final fix to boost finding on windows for cmake
(bzr r5256)
Diffstat (limited to 'CMakeScripts')
-rw-r--r--CMakeScripts/FindBoost.cmake9
1 files changed, 4 insertions, 5 deletions
diff --git a/CMakeScripts/FindBoost.cmake b/CMakeScripts/FindBoost.cmake
index 99ebf81dc..ba6778ec2 100644
--- a/CMakeScripts/FindBoost.cmake
+++ b/CMakeScripts/FindBoost.cmake
@@ -4,13 +4,12 @@
# BOOST_INCLUDE_DIR
-# To find boost on Windows, use BOOST_PATH variable set by mingwenv.bat:
-SET(env_boost_path "$ENV{BOOST_PATH}")
+# To find boost on Windows, use DEVLIBS_PATH variable set by mingwenv.bat
FIND_PATH(BOOST_INCLUDE_DIR boost/weak_ptr.hpp
/usr/include
/usr/local/include
- env_boost_path )
+ $ENV{DEVLIBS_PATH}//include )
IF (BOOST_INCLUDE_DIR)
@@ -18,9 +17,9 @@ IF (BOOST_INCLUDE_DIR)
ENDIF (BOOST_INCLUDE_DIR)
IF (BOOST_FOUND)
- MESSAGE(STATUS "Found Boost: ${BOOST_INCLUDE_DIR}")
+ MESSAGE(STATUS "boost: FOUND ( ${BOOST_INCLUDE_DIR} )")
ELSE(BOOST_FOUND)
- MESSAGE(FATAL_ERROR "Could not find Boost")
+ MESSAGE(FATAL_ERROR "boost: NOT FOUND")
ENDIF (BOOST_FOUND)